pitcharraytools
===============

.. automodule:: abjad.tools.pitcharraytools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.pitcharraytools.PitchArray.PitchArray
      ~abjad.tools.pitcharraytools.PitchArrayCell.PitchArrayCell
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn
      ~abjad.tools.pitcharraytools.PitchArrayInventory.PitchArrayInventory
      ~abjad.tools.pitcharraytools.PitchArrayRow.PitchArrayRow
